"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var postcss_1 = __importStar(require("postcss"));
var rtlcss_1 = __importDefault(require("rtlcss"));
var _types_1 = require("../@types");
var _constants_1 = require("../constants");
var containers_1 = require("../utilities/containers");
var declarations_1 = require("./declarations");
exports.getKeyFramesStringMap = function (keyframes) {
    var stringMap = {};
    keyframes.forEach(function (obj) {
        stringMap[obj.atRuleParams] = {
            name: obj.atRule.params,
            nameFlipped: obj.atRuleFlipped.params
        };
    });
    return stringMap;
};
exports.getKeyFramesRegExp = function (stringMap) { return new RegExp("(^| )(" + Object.keys(stringMap).join('|') + ")( |$)", 'g'); };
exports.parseAtRules = function (rules, keyFrameData, css, options) {
    containers_1.walkContainer(css, [_constants_1.AT_RULE_TYPE, _constants_1.RULE_TYPE], false, function (node) {
        if (node.type !== _constants_1.AT_RULE_TYPE)
            return;
        var atRule = node;
        if (postcss_1.vendor.unprefixed(atRule.name) === _constants_1.KEYFRAMES_NAME)
            return;
        atRule.walkRules(function (rule) {
            declarations_1.parseDeclarations(rules, keyFrameData, rule, options);
        });
    });
};
exports.parseKeyFrames = function (keyframes, css, options) {
    var source = options.source, processUrls = options.processUrls, useCalc = options.useCalc, stringMap = options.stringMap;
    containers_1.walkContainer(css, [_constants_1.AT_RULE_TYPE, _constants_1.RULE_TYPE], false, function (node) {
        if (node.type !== _constants_1.AT_RULE_TYPE)
            return;
        var atRule = node;
        if (postcss_1.vendor.unprefixed(atRule.name) !== _constants_1.KEYFRAMES_NAME)
            return;
        var atRuleString = atRule.toString();
        var atRuleFlippedString = rtlcss_1.default.process(atRuleString, { processUrls: processUrls, useCalc: useCalc, stringMap: stringMap });
        if (atRuleString === atRuleFlippedString)
            return;
        var rootFlipped = postcss_1.default.parse(atRuleFlippedString);
        var atRuleFlipped = rootFlipped.first;
        var atRuleParams = atRule.params;
        var ltr = atRuleParams + "-" + _types_1.Source.ltr;
        var rtl = atRuleParams + "-" + _types_1.Source.rtl;
        atRule.params = source === _types_1.Source.ltr ? ltr : rtl;
        atRuleFlipped.params = source === _types_1.Source.ltr ? rtl : ltr;
        keyframes.push({
            atRuleParams: atRuleParams,
            atRule: atRule,
            atRuleFlipped: atRuleFlipped
        });
    });
};
